@@ -93,6 +93,11 @@ public:
     */
     Q_REQUIRED_RESULT bool allowsTls() const;
 
+    /**
+      Returns true if the SMTP server has indicated that it allows Delivery Status Notification (DSN) support, false otherwise.
+    */
+    Q_REQUIRED_RESULT bool allowsDsn() const;
+
     /**
       @todo: return parsed auth modes, instead of strings.
     */
@@ -150,4 +155,3 @@ private:
     SessionPrivate *const d;
 };
 }
-
